@@ -1,4 +1,5 @@
 from typing import Optional
+
 from mindee.fields.base import Field
 
 
@@ -6,9 +7,15 @@ class Amount(Field):
     value: Optional[float] = None
 
     def __init__(
-        self, amount_prediction, value_key="amount", reconstructed=False, page_n=None
+        self,
+        amount_prediction: dict,
+        value_key: str = "amount",
+        reconstructed: bool = False,
+        page_n=None,
     ):
         """
+        Amount field object.
+
         :param amount_prediction: Amount prediction object from HTTP response
         :param value_key: Key to use in the amount_prediction dict
         :param reconstructed: Bool for reconstructed object (not extracted in the API)
