@@ -1,10 +1,13 @@
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Optional, TypeVar
 
 
 class Field:
     value: Optional[Any] = None
+    """Raw field value"""
     confidence: float = 0.0
+    """Confidence score"""
     bbox: List[List[float]] = []
+    """Bounding box coordinates containing the field"""
 
     def __init__(
         self,
@@ -43,52 +46,6 @@ class Field:
 
         self.reconstructed = reconstructed
 
-    @staticmethod
-    def compare_arrays(array1: list, array2: list, attr="value") -> bool:
-        """
-        Check that all elements are present in both arrays.
-
-        :param array1: Array of Fields
-        :param array2: Array of Fields
-        :param attr: Attribute to compare
-        :return: True if all elements in array1 exist in array2, False otherwise
-        """
-        set1 = {getattr(f1, attr) for f1 in array1}
-        set2 = {getattr(f2, attr) for f2 in array2}
-        return set1 == set2
-
-    @staticmethod
-    def array_confidence(array: list) -> float:
-        """
-        Multiply all Field's confidence in the array.
-
-        :param array: Array of fields
-        :return: Product as float
-        """
-        product = 1
-        for field in array:
-            try:
-                product *= field.confidence
-            except (AttributeError, TypeError):
-                return 0.0
-        return float(product)
-
-    @staticmethod
-    def array_sum(array: list) -> float:
-        """
-        Add all the Field values in the array.
-
-        :param array: Array of fields
-        :return: Sum as float.
-        """
-        array_sum = 0
-        for field in array:
-            try:
-                array_sum += field.value
-            except (AttributeError, TypeError):
-                return 0.0
-        return float(array_sum)
-
     def __eq__(self, other) -> bool:
         if self.value is None and other.value is None:
             return True
@@ -106,6 +63,10 @@ class Field:
 
 class TypedField(Field):
     type: str
+    """
+    The field type as defined by the API.
+    This is not a Python base type.
+    """
 
     def __init__(
         self,
@@ -121,3 +82,55 @@ class TypedField(Field):
         if self.value:
             return f"{self.type}: {self.value}"
         return ""
+
+
+TypeField = TypeVar("TypeField", bound=Field)
+TypeFieldList = List[TypeField]
+
+
+def compare_field_arrays(
+    array1: TypeFieldList, array2: TypeFieldList, attr="value"
+) -> bool:
+    """
+    Check that all elements are present in both arrays.
+
+    :param array1: Array of Fields
+    :param array2: Array of Fields
+    :param attr: Attribute to compare
+    :return: True if all elements in array1 exist in array2, False otherwise
+    """
+    set1 = {getattr(f1, attr) for f1 in array1}
+    set2 = {getattr(f2, attr) for f2 in array2}
+    return set1 == set2
+
+
+def field_array_confidence(array: TypeFieldList) -> float:
+    """
+    Multiply all Field's confidence in the array.
+
+    :param array: Array of fields
+    :return: Product as float
+    """
+    product = 1
+    for field in array:
+        try:
+            product *= field.confidence
+        except (AttributeError, TypeError):
+            return 0.0
+    return float(product)
+
+
+def field_array_sum(array: TypeFieldList) -> float:
+    """
+    Add all the Field values in the array.
+
+    :param array: Array of fields
+    :return: Sum as `float`.
+    """
+    arr_sum = 0
+    for field in array:
+        try:
+            arr_sum += field.value
+        except (AttributeError, TypeError):
+            return 0.0
+    return float(arr_sum)
