@@ -1,5 +1,5 @@
 import os
-from typing import Optional, Tuple
+from typing import Optional
 
 import requests
 
@@ -63,6 +63,14 @@ class Endpoint:
             f"{MINDEE_API_URL}/products/{self.owner}/{self.url_name}/v{self.version}"
         )
 
+    @property
+    def base_headers(self):
+        """Base headers to send with all API requests."""
+        return {
+            "Authorization": f"Token {self.api_key}",
+            "User-Agent": USER_AGENT,
+        }
+
     @property
     def envvar_key_name(self) -> str:
         """The API key name as stored in the environment."""
@@ -82,19 +90,6 @@ class Endpoint:
             self.api_key = env_key
             logger.debug("Set from environment: %s", self.envvar_key_name)
 
-    @staticmethod
-    def _read_document(
-        input_file: InputDocument, close_file: bool
-    ) -> Tuple[str, bytes]:
-        logger.debug("Reading data from: %s", input_file.filename)
-        input_file.file_object.seek(0)
-        data = input_file.file_object.read()
-        if close_file:
-            input_file.file_object.close()
-        else:
-            input_file.file_object.seek(0)
-        return input_file.filename, data
-
     def predict_request(
         self,
         input_file: InputDocument,
@@ -109,14 +104,16 @@ class Endpoint:
         :param close_file: Whether to `close()` the file after parsing it.
         :return: requests response
         """
-        files = {"document": self._read_document(input_file, close_file)}
-        headers = {"Authorization": self.api_key, "User-Agent": USER_AGENT}
+        files = {"document": input_file.read_contents(close_file)}
         data = {}
         if include_words:
             data["include_mvision"] = "true"
 
         response = requests.post(
-            f"{self._url_root}/predict", files=files, headers=headers, data=data
+            f"{self._url_root}/predict",
+            files=files,
+            headers=self.base_headers,
+            data=data,
         )
         return response
 
@@ -132,12 +129,14 @@ class CustomEndpoint(Endpoint):
         :return: requests response
         :param close_file: Whether to `close()` the file after parsing it.
         """
-        files = {"document": self._read_document(input_file, close_file)}
-        headers = {"Authorization": self.api_key, "User-Agent": USER_AGENT}
+        files = {"document": input_file.read_contents(close_file)}
         params = {"training": True, "with_candidates": True}
 
         response = requests.post(
-            f"{self._url_root}/predict", files=files, headers=headers, params=params
+            f"{self._url_root}/predict",
+            files=files,
+            headers=self.base_headers,
+            params=params,
         )
         return response
 
@@ -151,11 +150,9 @@ class CustomEndpoint(Endpoint):
         :param annotations: Annotations object
         :return: requests response
         """
-        headers = {"Authorization": self.api_key, "User-Agent": USER_AGENT}
-
         response = requests.post(
             f"{self._url_root}/documents/{document_id}/annotations",
-            headers=headers,
+            headers=self.base_headers,
             json=annotations,
         )
         return response
