@@ -2,13 +2,13 @@ import base64
 import io
 import os
 from mimetypes import guess_type
-from typing import BinaryIO, Optional
+from typing import BinaryIO, Optional, Tuple
 
 import pikepdf
 
 from mindee.logger import logger
 
-ALLOWED_EXTENSIONS = [
+ALLOWED_MIME_TYPES = [
     "image/png",
     "image/jpg",
     "image/jpeg",
@@ -20,12 +20,12 @@ INPUT_TYPE_FILE = "file"
 INPUT_TYPE_BASE64 = "base64"
 INPUT_TYPE_BYTES = "bytes"
 INPUT_TYPE_PATH = "path"
-INPUT_TYPE_DUMMY = "dummy"
 
 
 class InputDocument:
     file_object: BinaryIO
     filename: str
+    file_mimetype: str
     input_type: str
     filepath: Optional[str] = None
     cut_pdf: bool
@@ -39,17 +39,9 @@ class InputDocument:
     ):
         assert 0 < n_pdf_pages <= 3
         self.input_type = input_type
-        self.file_extension = guess_type(self.filename)[0]
+        self._check_mimetype()
 
-        if (
-            self.file_extension not in ALLOWED_EXTENSIONS
-            and self.input_type != INPUT_TYPE_DUMMY
-        ):
-            raise AssertionError(
-                "File type not allowed, must be in {%s}" % ", ".join(ALLOWED_EXTENSIONS)
-            )
-
-        if self.file_extension == "application/pdf":
+        if self.file_mimetype == "application/pdf":
             self.check_pdf_open()
             count_pages = self.count_pdf_pages()
             if cut_pdf is True:
@@ -61,6 +53,19 @@ class InputDocument:
                 raise AssertionError(f"PDF pages are empty in: {self.filename}")
         logger.debug("Loaded new document '%s' from %s", self.filename, self.input_type)
 
+    def _check_mimetype(self) -> None:
+        file_mimetype = guess_type(self.filename)[0]
+        if file_mimetype:
+            self.file_mimetype = file_mimetype
+        else:
+            raise AssertionError(f"Could not determine MIME type of '{self.filename}'")
+
+        if self.file_mimetype not in ALLOWED_MIME_TYPES:
+            raise AssertionError(
+                "File type not allowed, must be one of {%s}"
+                % ", ".join(ALLOWED_MIME_TYPES)
+            )
+
     def count_pdf_pages(self) -> int:
         """
         Count the pages in the PDF.
@@ -73,10 +78,10 @@ class InputDocument:
 
     def merge_pdf_pages(self, page_numbers: list) -> None:
         """
-        Create a new PDF from pages.
+        Create a new PDF from pages and set it to ``file_object``.
 
         :param page_numbers: List of pages number to use for merging in the original PDF.
-        :return: (void) Set the Input.file with the reconstructed pdf stream
+        :return: None
         """
         self.file_object.seek(0)
         new_pdf = pikepdf.Pdf.new()
@@ -91,7 +96,7 @@ class InputDocument:
         """
         Check if the PDF is empty.
 
-        :return: (void) Check if the document contain only empty pages
+        :return: ``True`` if the PDF is empty
         """
         self.file_object.seek(0)
         with pikepdf.open(self.file_object) as pdf:
@@ -126,6 +131,22 @@ class InputDocument:
         except Exception as err:
             raise RuntimeError("Couldn't open PDF file") from err
 
+    def read_contents(self, close_file: bool) -> Tuple[str, bytes]:
+        """
+        Read the contents of the input file.
+
+        :param close_file: whether to close the file after reading
+        :return: a Tuple with the file name and binary data
+        """
+        logger.debug("Reading data from: %s", self.filename)
+        self.file_object.seek(0)
+        data = self.file_object.read()
+        if close_file:
+            self.file_object.close()
+        else:
+            self.file_object.seek(0)
+        return self.filename, data
+
 
 class FileDocument(InputDocument):
     def __init__(
