@@ -1,5 +1,7 @@
 import json
+
 import pytest
+
 from mindee.documents.passport import Passport
 
 
@@ -9,25 +11,6 @@ def passport_object():
     return Passport(json_repsonse["document"]["inference"]["pages"][0]["prediction"])
 
 
-@pytest.fixture
-def passport_object_from_scratch():
-    return Passport(
-        country="FR",
-        id_number="sqd12354",
-        birth_date="1989-10-19",
-        expiry_date="2027-12-01",
-        issuance_date="2017-11-31",
-        birth_place="Paris",
-        gender="M",
-        surname="Doe",
-        mrz1="P<GBRPUDARSAN<<HENERT<<<<<<<<<<<<<<<<<<<<<<<",
-        mrz2="7077979792GBR9505209M1704224<<<<<<<<<<<<<<00",
-        given_names=["John", "Jane"],
-        mrz="P<GBRPUDARSAN<<HENERT<<<<<<<<<<<<<<<<<<<<<<<7077979792GBR9505209M1704224<<<<<<<<<<<<<<00",
-        full_name="John Doe",
-    )
-
-
 @pytest.fixture
 def passport_object_all_na():
     json_repsonse = json.load(open("./tests/data/passport/v1/passport_all_na.json"))
@@ -85,8 +68,3 @@ def test_wrong_checksum():
 def test_checksum_with_personal_number_alpha():
     mrz = "XDB0661884ESP9502138F1808122RE20050024133894"
     assert Passport.check_sum(mrz[28:42]) == mrz[42]
-
-
-def test_empty_object_works():
-    passport = Passport()
-    assert passport.full_name.value is None
